Index: trunk/DataCheck/QuickLook/RunGanymed.sh
===================================================================
--- trunk/DataCheck/QuickLook/RunGanymed.sh	(revision 18776)
+++ trunk/DataCheck/QuickLook/RunGanymed.sh	(revision 18777)
@@ -109,6 +109,9 @@
         case $check1 in
            1)   printprocesslog "INFO filling numevts.C was successfully for "$ganymedfile" and table "$resulttable1" (check1=$check1)"
-                # check result for alerts
-                `dirname $0`/FlareAlerts.sh
+                # check result for alerts (on daq only)
+                if [ "$HOSTNAME" = "daq" ]
+                then 
+                   `dirname $0`/FlareAlerts.sh
+                fi
                 ;;
            0)   printprocesslog "WARN connection to DB failed in numevts.C (check1=$check1)"
